@@ -1,5 +1,5 @@
 /*  core_mode.c - public functions for mode modules
- *  Copyright (C) 2000-2007  Jason Jordan <shnutils@freeshell.org>
+ *  Copyright (C) 2000-2008  Jason Jordan <shnutils@freeshell.org>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
@@ -28,7 +28,7 @@
 #include <sys/stat.h>
 #include "shntool.h"
 
-CVSID("$Id: core_mode.c,v 1.76 2007/01/01 06:21:53 jason Exp $")
+CVSID("$Id: core_mode.c,v 1.78 2008/02/18 23:25:13 jason Exp $")
 
 global_opts st_ops;
 
@@ -1470,6 +1470,14 @@ static void prog_init(progress_info *proginfo)
     proginfo->progress_shown = FALSE;
     prog_print_data(proginfo);
     proginfo->initialized = TRUE;
+    st_priv.screen_dirty = FALSE;
+  }
+
+  if (st_priv.screen_dirty) {
+    proginfo->last_percent = -1;
+    proginfo->progress_shown = FALSE;
+    prog_print_data(proginfo);
+    st_priv.screen_dirty = FALSE;
   }
 }
 
